@@ -50,7 +50,7 @@ except:
 # FUNCTIONS
 def what_is_DSH():
 
-    print("-General Information- \n\n Description: Data Science Helper is a open source library that intends to save time \n and make important data science operations without any effort. \n Library Name: Data Science Helper \n Language: Python \n Version: 1.5.1 \n Field: Data science and Machine Learning \n Purpose: Helping with data science operations and save time. \n Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy \n Github Link: https://github.com/bayhippo/Data-Science-Helper \n Author: Salih Albayrak \n First Creation Date: 7/31/2020 \n Documentation: https://github.com/bayhippo/Data-Science-Helper/wiki")    
+    print("-General Information- \n\n Description: Data Science Helper is a open source library that intends to save time \n and make important data science operations without any effort. \n Library Name: Data Science Helper \n Language: Python \n Version: 1.5.2 \n Field: Data science and Machine Learning \n Purpose: Helping with data science operations and save time. \n Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy \n Github Link: https://github.com/bayhippo/Data-Science-Helper \n Author: Salih Albayrak \n First Creation Date: 7/31/2020 \n Documentation: https://github.com/bayhippo/Data-Science-Helper/wiki")    
 
     # what fucntion prints
     """
@@ -60,7 +60,7 @@ def what_is_DSH():
     and make important data science operations without any effort. 
     Library Name: Data Science Helper 
     Language: Python 
-    Version: 1.5.1 
+    Version: 1.5.2 
     Field: Data science and Machine Learning 
     Purpose: Helping with data science operations and save time. 
     Used Libraries: Pandas, Numpy, Matplotlib, Seaborn, Scipy 
@@ -429,11 +429,11 @@ def outlier_detector(data, features, feature1, feature2, threshold, plotting = T
         plt.show()
 
     # dropping outliers and printing
-    x = x.drop(outlier_index)
+    data = data.drop(outlier_index)
     print("Number of Outliers(Number of Dropped Rows): {}".format(len(data) - x_len))
     print("Min Outlier Score: {}".format(np.min(outlier_score["score"])))
     
-    return x, outlier_score["score"]
+    return data, outlier_score["score"]
         
 
 def find_numericlike_categorical_features(data, features, filter_feature):
